"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var graphql_1 = require("graphql");
var fake_1 = require("./fake");
function fakeSchema(schema) {
    var fakeDirective = schema.getDirective('fake');
    var examplesDirective = schema.getDirective('examples');
    assert(fakeDirective != null && examplesDirective != null);
    var mutationType = schema.getMutationType();
    for (var _i = 0, _a = Object.values(schema.getTypeMap()); _i < _a.length; _i++) {
        var type = _a[_i];
        if (type instanceof graphql_1.GraphQLObjectType && !type.name.startsWith('__'))
            addFakeProperties(type);
        if (graphql_1.isAbstractType(type))
            type.resolveType = (function (obj) { return obj.__typename; });
    }
    ;
    function addFakeProperties(objectType) {
        var isMutation = (objectType === mutationType);
        for (var _i = 0, _a = Object.values(objectType.getFields()); _i < _a.length; _i++) {
            var field = _a[_i];
            if (isMutation && isRelayMutation(field))
                field.resolve = getRelayMutationResolver();
            else
                field.resolve = getFieldResolver(field, objectType);
        }
    }
    function isRelayMutation(field) {
        var args = field.args;
        if (args.length !== 1 || args[0].name !== 'input')
            return false;
        var inputType = args[0].type;
        // TODO: check presence of 'clientMutationId'
        return (inputType instanceof graphql_1.GraphQLNonNull &&
            inputType.ofType instanceof graphql_1.GraphQLInputObjectType &&
            field.type instanceof graphql_1.GraphQLObjectType);
    }
    function getFieldResolver(field, objectType) {
        var fakeResolver = getResolver(field.type, field);
        return function (source, _0, _1, info) {
            if (source && source.$example && source[field.name]) {
                return source[field.name];
            }
            var value = getCurrentSourceProperty(source, info.path);
            return (value !== undefined) ? value : fakeResolver(objectType);
        };
    }
    function getRelayMutationResolver() {
        return function (source, args, _1, info) {
            var value = getCurrentSourceProperty(source, info.path);
            if (value instanceof Error)
                return value;
            return __assign({}, args['input'], value);
        };
    }
    // get value or Error instance injected by the proxy
    function getCurrentSourceProperty(source, path) {
        return source && source[path.key];
    }
    function getResolver(type, field) {
        if (type instanceof graphql_1.GraphQLNonNull)
            return getResolver(type.ofType, field);
        if (type instanceof graphql_1.GraphQLList)
            return arrayResolver(getResolver(type.ofType, field));
        return fieldResolver(type, field);
    }
    function fieldResolver(type, field) {
        var _a = __assign({}, getFakeDirectives(type), getFakeDirectives(field)), fake = _a.fake, examples = _a.examples;
        if (graphql_1.isLeafType(type)) {
            if (examples)
                return function () { return fake_1.getRandomItem(examples.values); };
            if (fake) {
                return function () { return fake_1.fakeValue(fake.type, fake.options, fake.locale); };
            }
            return function () { return fakeLeafValue(type); };
        }
        else {
            // TODO: error on fake directive
            var possibleTypes_1 = graphql_1.isAbstractType(type)
                ? schema.getPossibleTypes(type)
                : [type];
            return function () { return (__assign({ __typename: fake_1.getRandomItem(possibleTypes_1) }, (examples ? fake_1.getRandomItem(examples.values) : {}), { $example: true })); };
        }
    }
    function getFakeDirectives(object) {
        var nodes = [];
        if (object.astNode != null) {
            nodes.push(object.astNode);
        }
        if (object.extensionNodes != null) {
            nodes.push.apply(nodes, object.extensionNodes);
        }
        var fake;
        var examples;
        for (var _i = 0, nodes_1 = nodes; _i < nodes_1.length; _i++) {
            var node = nodes_1[_i];
            fake = graphql_1.getDirectiveValues(fakeDirective, node);
            examples = graphql_1.getDirectiveValues(examplesDirective, node);
        }
        return (fake || examples) ? { fake: fake, examples: examples } : {};
    }
}
exports.fakeSchema = fakeSchema;
function arrayResolver(itemResolver) {
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var length = fake_1.getRandomInt(2, 4);
        var result = [];
        while (length-- !== 0)
            result.push(itemResolver.apply(void 0, args));
        return result;
    };
}
function fakeLeafValue(type) {
    if (type instanceof graphql_1.GraphQLEnumType) {
        var values = type.getValues().map(function (x) { return x.value; });
        return fake_1.getRandomItem(values);
    }
    var faker = fake_1.stdScalarFakers[type.name];
    if (faker)
        return faker();
    return "<" + type.name + ">";
}
//# sourceMappingURL=fake_schema.js.map