"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = require("lodash");
var graphql_1 = require("graphql");
var utils_1 = require("./utils");
function getProxyExecuteFn(url, headers, forwardHeaders) {
    //TODO: proxy extensions
    return function (args) {
        var schema = args.schema, document = args.document, contextValue = args.contextValue, operationName = args.operationName;
        var request = contextValue;
        var proxyHeaders = Object.create(null);
        for (var _i = 0, forwardHeaders_1 = forwardHeaders; _i < forwardHeaders_1.length; _i++) {
            var name = forwardHeaders_1[_i];
            proxyHeaders[name] = request.headers[name];
        }
        var strippedAST = removeUnusedVariables(stripExtensionFields(schema, document));
        var operations = graphql_1.separateOperations(strippedAST);
        var operationAST = operationName
            ? operations[operationName]
            : Object.values(operations)[0];
        return utils_1.graphqlRequest(url, __assign({}, headers, proxyHeaders), graphql_1.print(operationAST), args.variableValues, operationName).then(function (result) { return proxyResponse(result, args); });
    };
}
exports.getProxyExecuteFn = getProxyExecuteFn;
function proxyResponse(response, args) {
    var rootValue = response.data || {};
    var globalErrors = [];
    for (var _i = 0, _a = (response.errors || []); _i < _a.length; _i++) {
        var error = _a[_i];
        var message = error.message, path = error.path, extensions = error.extensions;
        var errorObj = new graphql_1.GraphQLError(message, undefined, undefined, undefined, path, undefined, extensions);
        if (!path) {
            globalErrors.push(errorObj);
            continue;
        }
        // Recreate root value up to a place where original error was thrown
        // and place error as field value.
        lodash_1.set(rootValue, error.path, errorObj);
    }
    if (globalErrors.length !== 0) {
        return { errors: globalErrors };
    }
    return graphql_1.execute(__assign({}, args, { rootValue: rootValue }));
}
function injectTypename(node) {
    return __assign({}, node, { selections: node.selections.concat([
            {
                kind: graphql_1.Kind.FIELD,
                name: {
                    kind: graphql_1.Kind.NAME,
                    value: '__typename',
                },
            },
        ]) });
}
function stripExtensionFields(schema, operationAST) {
    var _a;
    var typeInfo = new graphql_1.TypeInfo(schema);
    return graphql_1.visit(operationAST, graphql_1.visitWithTypeInfo(typeInfo, (_a = {},
        _a[graphql_1.Kind.FIELD] = function () {
            var fieldDef = typeInfo.getFieldDef();
            if (fieldDef.name.startsWith('__') || fieldDef.isExtensionField)
                return null;
        },
        _a[graphql_1.Kind.SELECTION_SET] = {
            leave: function (node) {
                var type = typeInfo.getParentType();
                if (graphql_1.isAbstractType(type) || node.selections.length === 0)
                    return injectTypename(node);
            }
        },
        _a)));
}
function removeUnusedVariables(documentAST) {
    var _a, _b;
    var seenVariables = Object.create(null);
    graphql_1.visit(documentAST, (_a = {},
        _a[graphql_1.Kind.VARIABLE_DEFINITION] = function () { return false; },
        _a[graphql_1.Kind.VARIABLE] = function (node) {
            seenVariables[node.name.value] = true;
        },
        _a));
    return graphql_1.visit(documentAST, (_b = {},
        _b[graphql_1.Kind.VARIABLE_DEFINITION] = function (node) {
            if (!seenVariables[node.variable.name.value]) {
                return null;
            }
        },
        _b));
}
//# sourceMappingURL=proxy.js.map